"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const swaggerUi = require("swagger-ui-express");
const yaml = require("js-yaml");
const fs = require("fs");
const path = require("path");
function setSwagger(app, route, filePath, options = {}) {
    try {
        const stats = fs.lstatSync(filePath);
        let swaggerDocument;
        if (options.concatenate) {
            if (stats.isFile()) {
                throw new Error('Boolean concatenate cannot be true when you specify a file. When you want to concatenate, specify a folder');
            }
            if (stats.isDirectory()) {
                const swaggerContent = buildSwaggerDocumentFromFiles(filePath);
                swaggerDocument = yaml.safeLoad(swaggerContent);
            }
        }
        else {
            if (stats.isFile()) {
                swaggerDocument = yaml.safeLoad(fs.readFileSync(filePath, 'utf8'));
            }
            if (stats.isDirectory()) {
                throw new Error('To concatenate a folder of swagger YMLS, you need to explicitly set the boolean concatenate on true for the swaggerOptions');
            }
        }
        const useSchema = (schema, options) => (...args) => swaggerUi.setup(schema, options)(...args);
        app.use(route, swaggerUi.serve, useSchema(swaggerDocument, options));
    }
    catch (e) {
        throw new Error(`Failed to load swagger documentation: ${e}`);
    }
}
exports.setSwagger = setSwagger;
function buildSwaggerDocumentFromFiles(filePath) {
    let swaggerDocument = '';
    try {
        swaggerDocument += fs.readFileSync(path.join(filePath, 'index.yml'), 'utf8');
        swaggerDocument += 'paths: \n';
    }
    catch (error) {
        throw new Error(`Could not read index.yml make sure the file is named: index.yml and in the correct folder ${error}`);
    }
    try {
        const routeFiles = fs.readdirSync(path.join(filePath, 'routes'));
        routeFiles.forEach((file) => {
            swaggerDocument += fs.readFileSync(path.join(filePath, 'routes', file), 'utf8');
        });
    }
    catch (error) {
        throw new Error(`Error while reading routes folder. Make sure there is one! , ${error}`);
    }
    return swaggerDocument;
}
